@@ -23,6 +23,12 @@ class Profile:
 		     |,4-  ) )-,_. ,\\ (  `'-'
 		    '---''(_/--'  `-'\\_)  miao miao 
 		'''
+		self.art2 = '''
+		 |\\__/,|   (`\
+		 |_ _   |.--.) )
+		 ( T    )     /
+		(((^_(((/(((_/
+		'''
 
 	def show_email(self):
 		if self.company != '':
@@ -33,6 +39,9 @@ class Profile:
 	def	show_myart(self):
 		print(self.art)
 
+	def	show_cat(self):
+		print(self.art2)	
+
 	def show_hobby(self):
 		if len(self.hobby) !=0:
 			print('--------my hobby--------')
@@ -51,5 +60,6 @@ if __name__ == '__main__':
 	my.show_email()
 	my.show_myart()
 	my.show_hobby()
+	my.show_cat()
 	#help(my)
 	
\ No newline at end of file
